@@ -17,7 +17,7 @@ is_ci = os.environ.get('CI', '').lower() == 'true'
 
 
 def qt_sources():
-    qtdir = os.environ.get('QT_SRC', '/usr/src/qt5/qtbase')
+    qtdir = os.environ.get('QT_SRC', '/usr/src/qt6/qtbase')
     j = partial(os.path.join, qtdir)
     return list(map(j, [
             'src/gui/kernel/qplatformtheme.cpp',
@@ -230,7 +230,7 @@ class POT(Command):  # {{{
             subprocess.check_call(['xgettext', '-f', fl.name,
                 '--default-domain=calibre', '-o', out.name, '-L', 'Python',
                 '--from-code=UTF-8', '--sort-by-file', '--omit-header',
-                '--no-wrap', '-k__', '--add-comments=NOTE:',
+                '--no-wrap', '-k__', '-kpgettext:1c,2', '--add-comments=NOTE:',
                 ])
             subprocess.check_call(['xgettext', '-j',
                 '--default-domain=calibre', '-o', out.name,
