@@ -158,7 +158,7 @@ class InterfaceAction(QObject):
             spec = self.action_spec
         text, icon, tooltip, shortcut = spec
         if icon is not None:
-            action = QAction(QIcon(I(icon)), text, self.gui)
+            action = QAction(QIcon.ic(icon), text, self.gui)
         else:
             action = QAction(text, self.gui)
         if attr == 'qaction':
@@ -229,7 +229,7 @@ class InterfaceAction(QObject):
             an UUID to it.
         :param text: The text of the action.
         :param icon: Either a QIcon or a file name. The file name is passed to
-            the I() builtin, so you do not need to pass the full path to the images
+            the QIcon.ic() builtin, so you do not need to pass the full path to the images
             folder.
         :param shortcut: A string, a list of strings, None or False. If False,
             no keyboard shortcut is registered for this action. If None, a keyboard
@@ -253,7 +253,7 @@ class InterfaceAction(QObject):
         ac = menu.addAction(text)
         if icon is not None:
             if not isinstance(icon, QIcon):
-                icon = QIcon(I(icon))
+                icon = QIcon.ic(icon)
             ac.setIcon(icon)
         keys = ()
         if shortcut is not None and shortcut is not False:
@@ -324,6 +324,16 @@ class InterfaceAction(QObject):
         '''
         pass
 
+    def library_about_to_change(self, olddb, db):
+        '''
+        Called whenever the current library is changed.
+
+        :param olddb: The LibraryDatabase corresponding to the previous library.
+        :param db: The LibraryDatabase corresponding to the new library.
+
+        '''
+        pass
+
     def library_changed(self, db):
         '''
         Called whenever the current library is changed.
