@@ -7,16 +7,13 @@ import shutil
 import sys
 from itertools import count
 from qt.core import (
-    QT_VERSION, QApplication, QBuffer, QByteArray, QEvent, QFontDatabase, QFontInfo,
-    QHBoxLayout, QIODevice, QLocale, QMimeData, QPalette, QSize, Qt, QTimer, QUrl,
-    QWidget, pyqtSignal, sip
-)
-from qt.webengine import (
-    QWebEngineUrlRequestJob, QWebEngineUrlSchemeHandler
+    QT_VERSION, QApplication, QByteArray, QEvent, QFontDatabase, QFontInfo,
+    QHBoxLayout, QLocale, QMimeData, QPalette, QSize, Qt, QTimer, QUrl, QWidget,
+    pyqtSignal, sip
 )
 from qt.webengine import (
     QWebEnginePage, QWebEngineProfile, QWebEngineScript, QWebEngineSettings,
-    QWebEngineView
+    QWebEngineUrlRequestJob, QWebEngineUrlSchemeHandler, QWebEngineView
 )
 
 from calibre import as_unicode, prints
@@ -26,18 +23,19 @@ from calibre.constants import (
 )
 from calibre.ebooks.metadata.book.base import field_metadata
 from calibre.ebooks.oeb.polish.utils import guess_type
-from calibre.gui2 import choose_images, error_dialog, safe_open_url, config
+from calibre.gui2 import choose_images, config, error_dialog, safe_open_url
 from calibre.gui2.viewer import link_prefix_for_location_links, performance_monitor
 from calibre.gui2.viewer.config import viewer_config_dir, vprefs
 from calibre.gui2.viewer.tts import TTS
-from calibre.gui2.webengine import (
-    Bridge, RestartingWebEngineView, create_script, from_js, insert_scripts,
-    secure_webengine, to_js
-)
+from calibre.gui2.webengine import RestartingWebEngineView
 from calibre.srv.code import get_translations_data
 from calibre.utils.localization import localize_user_manual_link
 from calibre.utils.serialize import json_loads
 from calibre.utils.shared_file import share_open
+from calibre.utils.webengine import (
+    Bridge, create_script, from_js, insert_scripts, secure_webengine, send_reply,
+    to_js
+)
 from polyglot.builtins import as_bytes, iteritems
 from polyglot.functools import lru_cache
 
@@ -94,21 +92,6 @@ def background_image():
     return ans
 
 
-def send_reply(rq, mime_type, data):
-    if sip.isdeleted(rq):
-        return
-    # make the buf a child of rq so that it is automatically deleted when
-    # rq is deleted
-    buf = QBuffer(parent=rq)
-    buf.open(QIODevice.OpenModeFlag.WriteOnly)
-    # we have to copy data into buf as it will be garbage
-    # collected by python
-    buf.write(data)
-    buf.seek(0)
-    buf.close()
-    rq.reply(mime_type.encode('ascii'), buf)
-
-
 @lru_cache(maxsize=2)
 def get_mathjax_dir():
     return P('mathjax', allow_user_override=False)
@@ -274,6 +257,7 @@ class ViewerBridge(Bridge):
     edit_book = from_js(object, object, object)
     show_book_folder = from_js()
     show_help = from_js(object)
+    update_reading_rates = from_js(object)
 
     create_view = to_js()
     start_book_load = to_js()
@@ -312,7 +296,7 @@ def apply_font_settings(page_or_view):
     else:
         s.resetFontFamily(QWebEngineSettings.FontFamily.SansSerifFont)
     sf = fs.get('standard_font') or 'serif'
-    sf = getattr(s, {'serif': 'SerifFont', 'sans': 'SansSerifFont', 'mono': 'FixedFont'}[sf])
+    sf = getattr(QWebEngineSettings.FontFamily, {'serif': 'SerifFont', 'sans': 'SansSerifFont', 'mono': 'FixedFont'}[sf])
     s.setFontFamily(QWebEngineSettings.FontFamily.StandardFont, s.fontFamily(sf))
     old_minimum = s.fontSize(QWebEngineSettings.FontSize.MinimumFontSize)
     old_base = s.fontSize(QWebEngineSettings.FontSize.DefaultFontSize)
@@ -472,11 +456,13 @@ class WebView(RestartingWebEngineView):
     scrollbar_context_menu = pyqtSignal(object, object, object)
     close_prep_finished = pyqtSignal(object)
     highlights_changed = pyqtSignal(object)
+    update_reading_rates = pyqtSignal(object)
     edit_book = pyqtSignal(object, object, object)
     shortcuts_changed = pyqtSignal(object)
     paged_mode_changed = pyqtSignal()
     standalone_misc_settings_changed = pyqtSignal(object)
     view_created = pyqtSignal(object)
+    content_file_changed = pyqtSignal(str)
 
     def __init__(self, parent=None):
         self._host_widget = None
@@ -534,6 +520,7 @@ class WebView(RestartingWebEngineView):
         self.bridge.scrollbar_context_menu.connect(self.scrollbar_context_menu)
         self.bridge.close_prep_finished.connect(self.close_prep_finished)
         self.bridge.highlights_changed.connect(self.highlights_changed)
+        self.bridge.update_reading_rates.connect(self.update_reading_rates)
         self.bridge.edit_book.connect(self.edit_book)
         self.bridge.show_book_folder.connect(self.show_book_folder)
         self.bridge.show_help.connect(self.show_help)
@@ -613,7 +600,7 @@ class WebView(RestartingWebEngineView):
         if family in ('.AppleSystemUIFont', 'MS Shell Dlg 2'):
             family = 'system-ui'
         ui_data = {
-            'all_font_families': QFontDatabase().families(),
+            'all_font_families': QFontDatabase.families(),
             'ui_font_family': family,
             'ui_font_sz': f'{fi.pixelSize()}px',
             'show_home_page_on_ready': self.show_home_page_on_ready,
@@ -637,11 +624,12 @@ class WebView(RestartingWebEngineView):
 
     def on_content_file_changed(self, data):
         self.current_content_file = data
+        self.content_file_changed.emit(self.current_content_file)
 
-    def start_book_load(self, initial_position=None, highlights=None, current_book_data=None):
+    def start_book_load(self, initial_position=None, highlights=None, current_book_data=None, reading_rates=None):
         key = (set_book_path.path,)
         book_url = link_prefix_for_location_links(add_open_at=False)
-        self.execute_when_ready('start_book_load', key, initial_position, set_book_path.pathtoebook, highlights or [], book_url)
+        self.execute_when_ready('start_book_load', key, initial_position, set_book_path.pathtoebook, highlights or [], book_url, reading_rates)
 
     def execute_when_ready(self, action, *args):
         if self.bridge.ready:
